@@ -42,6 +42,8 @@ class PreferencesDialog(QtGui.QDialog):
 
         self.ui.timezoneList.setCurrentIndex(timezones.indexOf(self.conf.get_timezone()))
         self.ui.pollingIntervalSpinBox.setValue(self.conf.get_interval())
+        self.ui.scriptCheckbox.setChecked(self.conf.get_custom_script_enabled())
+        self.ui.scriptLineEdit.setText(self.conf.get_custom_script())
     
     def item_selection_changed(self, status):
         self.ui.configureProjectButton.setEnabled(status)
@@ -86,5 +88,7 @@ class PreferencesDialog(QtGui.QDialog):
         self.conf.update_urls(self.get_urls())
         self.conf.set_interval(self.get_interval())
         self.conf.set_timezone(self.ui.timezoneList.currentText())
+        self.conf.set_custom_script(self.ui.scriptLineEdit.text(), self.ui.scriptCheckbox.isChecked())
+        self.conf.set_custom_script_enabled(self.ui.scriptCheckbox.isChecked())
         for key,value in self.get_selections():
             self.conf.set_value(key, value)
