@@ -1,10 +1,11 @@
 from PyQt4 import QtCore
+from PyQt4.QtCore import QThread
 
 class TimedEvent:
-    def __init__(self,parent, event_target):
+    def __init__(self,parent, event_target, interval = 2000):
         self.event_target = event_target
         self.parent = parent
-        self.interval = 2000
+        self.interval = interval
         
     def start(self):
         self.timer = QtCore.QTimer()
@@ -31,3 +32,12 @@ class RepeatTimedEvent:
         self.event_happened_count = self.event_happened_count + 1
         if (self.event_happened_count != self.repeat_count):
             self.start()
+
+class BackgroundEvent(QThread):
+    def __init__(self, task, parent=None):
+        QThread.__init__(self, parent)
+        self.task = task
+    
+    def run(self):
+        data = self.task()
+        self.emit(QtCore.SIGNAL('complete'), data)
